import React, { Component } from 'react'
import ReactDOM from 'react-dom'
import _ from 'lodash';

import { createStore, applyMiddleware, combineReducers, compose } from 'redux'
import { Provider, connect } from 'react-redux'
// import { Form, Control, Errors, combineForms, actions } from 'react-redux-form'
import thunk from 'redux-thunk';
import createLogger from 'redux-logger';

import {
  Field,
  Errors,
  Control,
  Form,
  LocalForm,
  combineForms,
  actions,
  formReducer,
  modeled
} from 'react-redux-form';

const initialUserState = {
  firstName: '',
  lastName: '',
};

const store = createStore(combineForms({
  user: initialUserState,
}), applyMiddleware(thunk));

class UserForm extends Component {
  constructor() {
    super();
    this.state = {
      form: {}
    }
  }
  render() {
    const errors = _.get(this.state, 'form.rate.errors', []);

    return (
      <LocalForm
        className="ui-form"
        onUpdate={(form) => {
          console.log(form);
          this.setState({ form })
        }}
        onSubmit={values => console.log(values)}
        style={{ marginTop: '3rem', maxWidth: '100%' }}
        initialState={{
          rate: ''
        }}
      >
        <div className="ui-field -third">
          <label className="ui-label">New Tax Rate</label>
          <span className="ui-input-group">
            <Control
              id="newRate"
              model=".rate"
              className="ui-input"
              type="number"
              placeholder="6"
              min={0.01}
              max={100}
              step=".01"
            />
            <span>%</span>
            <p>{Object.keys(errors).length ? 'Found errors' : 'No errors'}</p>
            <button
              className="ui-button -inline"
              style={{ height: '2.5rem', width: '15rem' }}
              disabled={!this.state.formValid || this.state.formPending}
            >
              {this.state.formPending ? 'Saving...' : 'Add Rate'}
            </button>
          </span>
          <Errors
            model=".rate"
            className="ui-error"
            messages={{
              stepMismatch: 'Decimal limited to two places',
              rangeUnderflow: 'The smallest rate is .01%',
              rangeOverflow: 'The most you can apply is 100%',
            }}
          />
        </div>

      </LocalForm>
    )
  }
}

class App extends React.Component {
  render() {
    return (
      <Provider store={store}>
        <UserForm />
      </Provider>
    );
  }
}

ReactDOM.render(<App />, document.getElementById('app'));
